<?php
require_once('conn.php');
session_start();
if (isset($_SESSION['region'])) {
    header('location:../regionalcoord/dashboard.php');
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Regional Coordinator Login</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css">
    <link href="images/icon2.png" rel="icon">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>


    <style>
        body {
            background-color: #f4f6f9;
            display: flex;
            align-items: center;
            justify-content: center;
            height: 100vh;
            transition: background-color 0.3s, color 0.3s;
        }
        .login-container {
            width: 500px;
            padding: 30px;
            background: white;
            border-radius: 10px;
            box-shadow: 0px 0px 10px rgba(0, 0, 0, 0.1);
            transition: background 0.3s, box-shadow 0.3s;
        }
        .login-container h3 {
            text-align: center;
            margin-bottom: 20px;
            color: #007cc0;
        }
        /* Dark mode styles */
        body.dark-mode {
            background-color: #121212;
            color: white;
        }
        .login-container.dark-mode {
            background: #1c1c1c;
            box-shadow: 0px 0px 10px rgba(255, 255, 255, 0.1);
        }
        .toggle-btn2 button {
            border: none;
            background: none;
            cursor: pointer;
            position: absolute;
            top: 20px;
            right: 20px;
            z-index: 10;
        }
        .dark-mode .toggle-text {
            color: white;
        }
    </style>
</head>
<body>

<!-- Dark Mode Toggle Button -->
<div class="toggle-btn2" id="darkModeToggle">
    <button class="btn btn-light">
        <i class="fa fa-moon"></i> <span class="toggle-text">Dark Mode</span>
    </button>
</div>

<div class="login-container">
    <h3>Regional Coordinator Login</h3>
    <form method="post" action="<?php echo htmlspecialchars($_SERVER['PHP_SELF']); ?>">
        <?php
        require_once "conn.php"; // Ensure database connection is included
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['reg'])) {
            $password = trim($_POST['password']);
            $region = trim($_POST['region']);
            $email = trim($_POST['email']);

         

            // Correct query using region as a number
            $sql = "SELECT * FROM region WHERE region = :region AND email = :email";
            $stmt = $conn->prepare($sql);
            $stmt->execute(['region' => $region, 'email' => $email]);
            $user = $stmt->fetch(PDO::FETCH_ASSOC);

            if (!$user) {
                echo "<div class='alert alert-danger'>Email not found</div>";
            } else {
                if ($password !== $user['password']) {
                    echo "<div class='alert alert-danger'>Wrong password</div>";
                } else {
                    $_SESSION['region'] = $user['region'];
                    $_SESSION['email'] = $user['email'];
                    header("Location: ./dash.php");
                    exit;
                }
            }
        }
        ?>
        <div class="mb-3">
            <label for="region" class="form-label"><i class="fa fa-map-marker-alt"></i> Select Your Region</label>
            <div class="input-group">
                <span class="input-group-text"><i class="fa fa-globe"></i></span>
                <select class="form-select" name="region" id="region" required onchange="generateEmail()">
                    <option disabled selected>SELECT YOUR REGION</option>
                    <?php 
                    for ($i = 1; $i <= 69; $i++) echo "<option value='$i'>Region $i</option>"; 
                    ?>
                    <option value="Continental 1 Headquarters">Continental 1 Headquarters</option>
                    <option value="Continental 2 Headquarters">Continental 2 Headquarters</option>
                    <option value="Continental 3 Headquarters">Continental 3 Headquarters</option>
                    <option value="National Headquarters">National Headquarters</option>
                    <option value="Redemption City">Redemption City</option>
                </select>
            </div>
        </div>

        <div class="mb-3">
            <label for="email" class="form-label"><i class="fa fa-envelope"></i> Email</label>
            <div class="input-group">
                <span class="input-group-text"><i class="fa fa-envelope"></i></span>
                <input type="email" class="form-control" name="email" id="email" placeholder="Auto-generated email" required readonly>
            </div>
        </div>

        <div class="mb-3">
            <label for="password" class="form-label"><i class="fa fa-lock"></i> Password</label>
            <div class="input-group">
                <span class="input-group-text"><i class="fa fa-key"></i></span>
                <input type="password" class="form-control" id="password" name="password" placeholder="Enter your password" required>
                <button class="btn btn-outline-secondary" type="button" onclick="togglePassword()"><i class="fa fa-eye"></i></button>
            </div>
        </div>

        <button type="submit" class="btn btn-primary w-100" name="reg"><i class="fa fa-sign-in-alt"></i> Login</button>
    </form>
    
    <div class="text-center mt-3">
        <a href="#"><i class="fa fa-question-circle"></i> Forgot Password?</a> | 
        <a href="#"><i class="fa fa-info-circle"></i> Need Help?</a>
    </div>
</div>

<script>
    // Toggle password visibility
    function togglePassword() {
        let passwordInput = document.getElementById('password');
        passwordInput.type = (passwordInput.type === 'password') ? 'text' : 'password';
    }

    // Generate email based on region selection
    function generateEmail() {
        let regionSelect = document.getElementById("region");
        let emailInput = document.getElementById("email");
        let selectedRegion = regionSelect.value.trim(); // Get selected region value

        // If the value is a number (1-69), generate region email
        if (!isNaN(selectedRegion) && selectedRegion >= 1 && selectedRegion <= 69) {
            emailInput.value = `region${selectedRegion}@rccgjuniorchurch.org`;
        } 
        // If the value is not a number, convert it into an email format
        else {
            let formattedRegion = selectedRegion.toLowerCase().replace(/\s+/g, ''); // Remove spaces and lowercase
            emailInput.value = `${formattedRegion}@rccgjuniorchurch.org`;
        }
    }

    $(document).ready(function() {
    // Dark mode toggle functionality
    $("#darkModeToggle").click(function () {
        // Toggle the dark mode class on the body
        $("body").toggleClass("dark-mode");
        $(".login-container").toggleClass("dark-mode");

        // Toggle button text and icon
        if ($("body").hasClass("dark-mode")) {
            $("#darkModeToggle button").html('<i class="fa fa-sun"></i> Light Mode'); // Update for light mode
            $("#darkModeToggle button").removeClass("btn-light").addClass("btn-dark"); // Change button color to dark mode
        } else {
            $("#darkModeToggle button").html('<i class="fa fa-moon"></i> Dark Mode'); // Update for dark mode
            $("#darkModeToggle button").removeClass("btn-dark").addClass("btn-light"); // Change button color to light mode
        }
    });
});

</script>


</body>
</html>
